# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='LauraGiant',
    version='0.0.1',
    url='https://github.com/brunofisico/laura_gigantes',
    license='MIT License',
    author='Bruno Lustosa de Moura ',
    author_email='bruno.moura@ifrn.edu.br',
    keywords='Red Giants Analysis Time-Series Asteroseismology',
    description=u'Código aberto para uso em analise de estrelas gigantes observadas pelo Kepler',
    packages=find_packages(),
    install_requires=[],
    test_suite='test',
)
